@@ -263,13 +263,13 @@ static void undo_unzip(const char* zip_extraction_directory_name)
 	
 	if (zip_extraction_directory_name[0] == '/' && zip_extraction_directory_name[1] == 0)
 	{
-		error ("tried to remove the root directory \"/\". This is a serious program bug. Please report to <danny.milo@scratchpost.org>");
+		error("tried to remove the root directory \"/\". This is a serious program bug. Please report to <danny.milo@scratchpost.org>");
 		return; /* chicken */
 	}
 	
 	if (!g_spawn_sync(NULL, (char**) argv, NULL, 0, NULL, NULL, NULL, NULL, &exit_code, NULL) || exit_code != 0) {
 		/* unzip printed reason to stderr */
-		error ("could not delete directory \"%s\"", zip_extraction_directory_name);
+		error("could not delete directory \"%s\"", zip_extraction_directory_name);
 		/* ignore error... */
 	}
 	
@@ -299,11 +299,12 @@ static int unzip_file(const char* zip_file_name, const char* zip_extraction_dire
 		NULL
 	};
 	GPid child_pid;
-	char text [100];
+	char text[2049];
 	
 	/* Display a HildonBanner to the user */
-	snprintf (text, sizeof (text), "Unzipping %s", g_basename (zip_file_name));
-	osso_system_note_infoprint (osso_context, text, NULL);
+	if (snprintf(text, sizeof(text), "Unzipping \"%s\"", g_basename (zip_file_name)) != -1) {
+		osso_system_note_infoprint(osso_context, text, NULL);
+	}
 	
 	if (!g_spawn_async(NULL, (char**) argv, NULL, G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, &child_pid, NULL)) {
 		/* unzip printed reason to stderr */
@@ -436,7 +437,7 @@ int main(int argc, char* argv[])
 	
 	gtk_init(&argc, &argv);
 	
-	osso_context = osso_initialize("batch_unzip", "1.0", FALSE, NULL);
+	osso_context = osso_initialize("unzip_fm", "1.0", FALSE, NULL);
 	if (osso_context == NULL) {
 		g_error("could not register document handler service");
 		exit(1);
